/* 
    JSPWiki - a JSP-based WikiWiki clone.

    Copyright (C) 2001-2003 Janne Jalkanen (Janne.Jalkanen@iki.fi)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation; either version 2.1 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.ecyrd.jspwiki.auth;

/**
 *  Thrown in some error situations where a WikiPrincipal object does not exist.
 *  @author Andrew Jaquith
 *  @since 2.3
 */
public final class NoSuchPrincipalException
    extends WikiSecurityException
{
    private static final long serialVersionUID = 3257849895976186169L;

    /**
     * Constructs a new exception object with a supplied message.
     * @param msg the message
     */
    public NoSuchPrincipalException( String msg )
    {
        super(msg);
    }
}
